/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package itso.ad.presentation.servlet;

import itso.ad.business.framework.factory.BusinessDelegateFactory;
import itso.ad.common.logging.LogHelper;

import java.util.Properties;

import javax.servlet.Servlet;
import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;

public class ApplicationInitServlet extends HttpServlet implements Servlet {
	private static LogHelper log = LogHelper.getInstance(ApplicationInitServlet.class);
	
	/* (non-Java-doc)
	 * @see javax.servlet.http.HttpServlet#HttpServlet()
	 */
	public ApplicationInitServlet() {
		super();
	}

	/* (non-Java-doc)
	 * @see javax.servlet.Servlet#init(ServletConfig arg0)
	 */
	public void init(ServletConfig arg0) throws ServletException {
		String piggyBankConfigFile = arg0.getInitParameter("itso.ad.presentation.servlet.properties");
		  // ensure init parameters (as detailed in the web.xml) are present
		  if (piggyBankConfigFile == null)
			throw new ServletException("No 'piggybank-config-file' Init Parameter supplied in web.xml");

		  try {
		    
		   	Properties properties = new Properties();
			properties.load(new java.io.FileInputStream(arg0.getServletContext().getRealPath(piggyBankConfigFile)));
			// initialize the delegate factory
			BusinessDelegateFactory.init(properties.getProperty("itso.ad.business.delegate.factory"));

			log.info("PIGGY_BANK_SERVLET - Initialisation complete [ok]");

		  } catch (Exception e) {
			String msg = e.getClass().getName() + ", on application initialization , message: " + e.getMessage();
			if (log != null) {
			  log.error("PIGGY_BANK_SERVLET has failed to start up correctly, message: " + e.getMessage());
			  log.error(msg, e);
			}
		  
			throw new ServletException(msg, e);
		  }
	}

}