/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */


package itso.ad.presentation.servlet;

import itso.ad.business.framework.exception.ServiceException;
import itso.ad.business.framework.factory.BusinessDelegateFactory;
import itso.ad.business.framework.interfaces.delegates.IPiggyBankBusinessDelegate;
import itso.ad.business.framework.interfaces.to.ICustomerTO;
import itso.ad.common.logging.LogHelper;

import java.io.IOException;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

public abstract class BaseServlet extends HttpServlet implements Servlet {
	
	protected static LogHelper log = LogHelper.getInstance(BaseServlet.class);

//	 only for unit testing
	private ServletContext context = null;
	/* (non-Java-doc)
	 * @see javax.servlet.http.HttpServlet#HttpServlet()
	 */
	public BaseServlet() {
		super();
	
	}

	/* (non-Java-doc)
	 * @see javax.servlet.http.HttpServlet#doGet(HttpServletRequest arg0, HttpServletResponse arg1)
	 */
	protected void doGet(HttpServletRequest arg0, HttpServletResponse arg1) throws ServletException, IOException {
		this.performTask(arg0, arg1);
	}

	/* (non-Java-doc)
	 * @see javax.servlet.http.HttpServlet#doPost(HttpServletRequest arg0, HttpServletResponse arg1)
	 */
	protected void doPost(HttpServletRequest arg0, HttpServletResponse arg1) throws ServletException, IOException {
		this.performTask(arg0, arg1);
	}
	
	/**
	 * @return
	 */
	public ServletContext getContext() {
		return context;
	}

	/**
	 * @param context
	 */
	public void setContext(ServletContext context) {
		this.context = context;
	}
	
	protected IPiggyBankBusinessDelegate getPiggyBankService() throws ServiceException{
		return BusinessDelegateFactory.getInstance().createPiggyBankBusinessDelegate();
	}

	protected ICustomerTO getCustomer(HttpServletRequest request) throws ServiceException {
		if (request.getRemoteUser() != null)
			// with security
			return getPiggyBankService().getCustomerById(request.getRemoteUser());
		else {
			// without security
			String customerId = null;
			HttpSession session = request.getSession(true);
			if (request.getParameter("j_username") != null) {
				customerId = (String)request.getParameter("j_username");
				session.setAttribute("customerid", customerId);
			} else {
				customerId = (String)session.getAttribute("customerid");
			}
			if (customerId == null) throw new ServiceException("No user identified");
			return getPiggyBankService().getCustomerById(customerId);
		}		
	}
	
	protected abstract void performTask(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException;

	protected void handleException(Exception e, HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
		log.error(e.getMessage(), e);
		req.setAttribute("serviceException", e);
		forwardTo("/secure/ErrorMessage.jsp", req, resp);
	}

	protected void forwardTo(String pageName, HttpServletRequest req, HttpServletResponse resp) throws IOException, ServletException {
		// real application
		this.getServletContext().getRequestDispatcher(pageName).forward(req, resp);
		// JUnit only
		// this.getContext().getRequestDispatcher(pageName).forward(req, resp);
	}

}
