/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.
 *| (C) Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |	
 *+--------------------------------------------------------------------------------------+
 */
package itso.ad.citybank.dao;

import javax.naming.InitialContext;

import itso.ad.business.framework.exception.DataAccessException;
import itso.ad.citybank.CityBank;
import itso.ad.citybank.CityBankServiceLocator;

public class CityBankDataAccessObject {

	public CityBankDataAccessObject() {
		super();
	}

	/** 
	 * Validate a check against CityBank.
	 * This method uses JSR101 Web service call style.
	 * @param checkReference
	 * @param amount
	 * @return true if check valid, false otherwise
	 * @throws DataAccessException
	 */
	
	public boolean checkCityBankAccount(String checkReference, int amount)
		throws DataAccessException {
		try {
			// get proxy JSR 101
			CityBankServiceLocator loc = new CityBankServiceLocator();
			CityBank proxy = loc.getCityBank(); // returns "stub"
			
			// call Web service
			boolean isCheckValid = proxy.validateCheck(checkReference, amount);
			return isCheckValid;
		} catch (Exception e) {
			throw new DataAccessException(e.getMessage(), e);
		}
	}
	
	
	/** 
	 * Validate a check against CityBank.
	 * This method uses JSR109 Web service call style.
	 * @param checkReference
	 * @param amount
	 * @return true if check valid, false otherwise
	 * @throws DataAccessException
	 */
	
	public boolean checkCityBankAccount109(String checkReference, int amount)
		throws DataAccessException {
		try {
			// get proxy JSR 109: JNDI lookup
			InitialContext ic = new InitialContext();
			CityBankServiceLocator loc =
				(CityBankServiceLocator) ic.lookup(
					"java:comp/env/service/CityBankService");
			CityBank proxy = (CityBank) loc.getPort(CityBank.class);
			
			// call Web service
			boolean isCheckValid = proxy.validateCheck(checkReference, amount);
			return isCheckValid;
		} catch (Exception e) {
			throw new DataAccessException(e.getMessage(), e);
		}
	}
	

}
